"""
All configurations for pyeventroute
"""


from pytconf import Config


class ConfigRoute(Config):
    """
    Config default router
    """
